@@ -45,8 +45,10 @@ class fileDM:
         by seeking to this byte number.
     dataShape : list
         The total number of dimensions in eahc dataset. Similar to numpy's ndims attribute for an ndarray.
-    filename : str
-        The path to the file as a string
+    file_name : str
+        The name of the file
+    file_path : pathlib.Path
+        A pathlib.Path object for the open file
     fid : file
         The file handle.
     numObjects : list
@@ -70,18 +72,16 @@ class fileDM:
     Examples
     --------
     Read data from a file containing a single image into memory
-
-    >>> from ncempy.io import dm
-    >>> with dm.fileDM('filename.dm4') as dmFile1:
-    >>>     dataSet = dmFile1.getDataset(0)
+    >> from ncempy.io import dm
+    >> with dm.fileDM('filename.dm4') as dmFile1:
+    >>     dataSet = dmFile1.getDataset(0)
 
     Example of reading a full multi-image DM3 file into memory:
-
-    >>> with dm.fileDM('imageSeries.dm3')as dmFile2:
-    >>>     series = dmFile2.getDataset(0)
+    >> with dm.fileDM('imageSeries.dm3')as dmFile2:
+    >>     series = dmFile2.getDataset(0)
     """
 
-    __slots__ = ('filename', 'fid', '_on_memory', '_v', 'xSize', 'ySize',
+    __slots__ = ('file_name', 'file_path', 'fid', '_on_memory', '_v', 'xSize', 'ySize',
                  'zSize', 'zSize2', 'dataType', 'dataSize', 'dataOffset',
                  'dataShape', 'numObjects', 'thumbnail', '_curGroupLevel',
                  '_maxDepth', '_curGroupAtLevelX', '_curGroupNameAtLevelX',
@@ -98,7 +98,7 @@ class fileDM:
 
         Parameters
         ----------
-        filename : str or pathlib.Path
+        filename : str or pathlib.Path or file object
             String pointing to the filesystem location of the file.
 
         verbose : bool, optional, default False
@@ -111,49 +111,56 @@ class fileDM:
             improve reading in all cases.
 
         """
-        self.filename = filename
-
-        # necessary declarations, if something fails
-        self.fid = None
-
-        self._on_memory = on_memory
-
-        # check filename type
-        if isinstance(filename, str):
-            pass
-        elif isinstance(filename, Path):
-            filename = str(filename)
-        else:
-            raise TypeError('Filename is supposed to be a string or pathlib.Path')
 
         # Add a top level variable to indicate verbose output for debugging
         self._v = verbose
 
-        # try opening the file
-        try:
-            if not self._on_memory:
-                self.fid = open(filename, 'rb')
-            if self._on_memory:
-                self._buffer_offset = 0
-                # Pre-load the file as a memory map that supports operations
-                # similar to a file.
-                with open(filename, 'rb') as _fid:
-                    if os.name == 'nt':
-                        self.fid = mmap.mmap(_fid.fileno(), 0,
-                                             access=mmap.ACCESS_READ)
-                    else:
-                        self.fid = mmap.mmap(_fid.fileno(), 0,
-                                             prot=mmap.PROT_READ)  # , flags=mmap.MAP_PRIVATE)
-                    self._buffer_size = filestats(filename).st_size
+        # Check for read() to determine if this is a file object
+        if hasattr(filename, 'read'):
+            self.fid = filename
+            self._on_memory = False
+            try:
+                self.file_name = self.fid.name
+            except AttributeError:
+                self.file_name = None
+        else:
+            self._on_memory = on_memory
 
-        except IOError:
-            print('Error reading file: "{}"'.format(filename))
-            raise
-        except:
-            raise
+            # check filename type. Prefer pathlib.Path
+            if isinstance(filename, str):
+                filename = Path(filename)
+            elif isinstance(filename, Path):
+                pass
+            else:
+                raise TypeError('Filename is supposed to be a string or pathlib.Path')
+
+            self.file_path = filename
+            self.file_name = self.file_path.name
+
+            # try opening the file
+            try:
+                if not self._on_memory:
+                    self.fid = open(self.file_path, 'rb')
+                if self._on_memory:
+                    self._buffer_offset = 0
+                    # Pre-load the file as a memory map that supports operations
+                    # similar to a file.
+                    with open(self.file_path, 'rb') as _fid:
+                        if os.name == 'nt':
+                            self.fid = mmap.mmap(_fid.fileno(), 0,
+                                                 access=mmap.ACCESS_READ)
+                        else:
+                            self.fid = mmap.mmap(_fid.fileno(), 0,
+                                                 prot=mmap.PROT_READ)  # , flags=mmap.MAP_PRIVATE)
+                        self._buffer_size = filestats(self.file_path).st_size
+            except IOError:
+                print('Error reading file: "{}"'.format(self.file_apth))
+                raise
+            except:
+                raise
 
         if not self._validDM():
-            raise IOError('Can not read file: {}'.format(filename))
+            raise IOError('Can not read file: {}'.format(self.file_path))
 
         # Lists that will contain information about binary data arrays
         self.xSize = []
@@ -192,10 +199,10 @@ class fileDM:
         self._scale_temp = 0
         self._origin_temp = 0
 
-        self._encodedTypeSizes = {0: 0, 8: 1, 9: 1, 10: 1,
-                                  2: 2, 4: 2,
-                                  3: 4, 5: 4, 6: 4,
-                                  7: 8, 12: 8}
+        self._encodedTypeSizes = {0: 0, 2: 2, 3: 4, 4: 2,
+                                  5: 4, 6: 4, 7: 8,
+                                  8: 1, 9: 1, 10: 1,
+                                  11: 8, 12: 8}
 
         self._DM2NPDataTypes = {1: np.int16, 2: np.float32,
                                 3: np.complex64, 6: np.uint8,
@@ -223,7 +230,7 @@ class fileDM:
         """
         if not self.fid.closed:
             if self._v:
-                print('Closing input file: {}'.format(self.filename))
+                print('Closing input file: {}'.format(self.file_path))
             self.fid.close()
 
     def __enter__(self):
@@ -844,17 +851,14 @@ class fileDM:
                 Allow user to define a different path than the directory of the current file.
 
         """
-        file_name = Path(self.filename)
-        new_file_name = Path(file_name.stem + '_tags').with_suffix('.txt')
+        new_file_name = Path(self.file_path.stem + '_tags').with_suffix('.txt')
 
         # Change output path
         if new_folder_path_for_tags:
             print('choosing different path')
             out_directory = Path(new_folder_path_for_tags)
         else:
-            out_directory = file_name.parent
-
-        print(out_directory)
+            out_directory = self.file_path.parent
 
         try:
             # open a text file to write out the tags
@@ -961,7 +965,7 @@ class fileDM:
 
         outputDict = {}
 
-        outputDict['filename'] = os_basename(self.filename)
+        outputDict['filename'] = self.file_name
 
         # Parse the dataset to see what type it is (image, image series, spectra, etc.)
         if self.xSize[ii] > 0:
@@ -1058,7 +1062,7 @@ class fileDM:
 
         self.seek(self.fid, self.dataOffset[ii], 0)  # Seek to start of dataset from beginning of the file
 
-        outputDict = {'filename': os_basename(self.filename)}
+        outputDict = {'filename': self.file_name}
 
         # Parse the dataset to see what type it is (image, 3D image series, spectra, 4D, etc.)
         if self.xSize[ii] > 0:
@@ -1146,7 +1150,7 @@ class fileDM:
         sh0 = (self.zSize2[ii], self.zSize[ii], self.ySize[ii], self.xSize[ii])
         sh1 = tuple([ii for ii in sh0 if ii > 1])  # shape must be a tuple
 
-        mm = np.memmap(self.filename, dtype=self._DM2NPDataType(self.dataType[ii]), mode='r',
+        mm = np.memmap(self.file_path, dtype=self._DM2NPDataType(self.dataType[ii]), mode='r',
                        offset=self.dataOffset[ii], shape=sh1)
 
         return mm
@@ -1182,10 +1186,10 @@ def dmReader(filename, dSetNum=0, verbose=False, on_memory=True):
 
     Example
     -------
-        Load all data from a single image dm3 file and display it
-            >>> from ncempy.io import dm
-            >>> im0 = dm.dmReader('filename.dm3')
-            >>> plt.imshow(im0['data']) #show the single image from the data file
+        Load data from a single image dm3 file and display it
+        >> from ncempy.io import dm
+        >> im0 = dm.dmReader('filename.dm3')
+        >> plt.imshow(im0['data']) #show the single image from the data file
     """
     # Open the file
     with fileDM(filename, verbose, on_memory=on_memory) as f1:
@@ -1208,3 +1212,6 @@ def dmReader(filename, dSetNum=0, verbose=False, on_memory=True):
     del im1['pixelOrigin']
 
     return im1  # return the dataset and metadata as a dictionary
+
+if __name__ == '__main__':
+    print('hi')
\ No newline at end of file
