@@ -25,6 +25,10 @@ class fileMRC:
 
     Attributes
     ----------
+    file_name : str
+        The name of the file
+    file_path : pathlib.Path
+        A pathlib.Path object for the open file
     fid : file
         The file handle to the opened MRC file.
     mrcType : int
@@ -60,39 +64,52 @@ class fileMRC:
     Examples
     --------
     Read in all data and metadata into memory.
-
-    >>> import ncempy.io as nio
-    >>> mrc0 = nio.mrc.mrcReader('file.mrc')
+    >> import ncempy.io as nio
+    >> mrc0 = nio.mrc.mrcReader('file.mrc')
 
     Low level operations to get 1 slice of the 3D data
-
-    >>> import ncempy.io as nio
-    >>> with nio.mrc.fileMRC('file.mrc') as f1:
-    >>>     single_slice = f1.getSlice(0)
+    >> import ncempy.io as nio
+    >> with nio.mrc.fileMRC('file.mrc') as f1:
+    >>     single_slice = f1.getSlice(0)
     """
 
     def __init__(self, filename, verbose=False):
         """
         Parameters
         -----------
-            filename: str or pathlib.Path
-                String or pathlib.Path object pointing to the filesystem location of the file.
+            filename : str or pathlib.Path or file object
+                String or pathlib.Path of file object pointing to the filesystem location of the file.
             verbose : bool
                 If True, debug information is printed.
 
         """
         # check filename type
-        if isinstance(filename, str):
-            pass
-        elif isinstance(filename, Path):
-            filename = str(filename)
+        if hasattr(filename, 'read'):
+            self.fid = filename
+            try:
+                self.file_path = Path(self.fid.name)
+                self.file_name = self.file_path.name
+            except AttributeError:
+                self.file_name = None
+                self.file_path = None
         else:
-            raise TypeError('Filename is supposed to be a string or pathlib.Path')
+            if isinstance(filename, str):
+                filename = Path(filename)
+            elif isinstance(filename, Path):
+                pass
+            else:
+                raise TypeError('Filename is supposed to be a string or pathlib.Path or readable file object')
 
-        self.filename = filename
+            self.file_path = filename
+            self.file_name = filename.name
+
+            # Open the file and quit if the file does not exist
+            try:
+                self.fid = open(self.file_path, 'rb')
+            except IOError as e:
+                print("I/O error({0}): {1}".format(e.errno, e.strerror))
 
         # necessary declarations, if something fails
-        self.fid = None
         self.mrcType = None
         self.dataType = None
         self.dataSize = None
@@ -111,15 +128,6 @@ class fileMRC:
         # Add a top level variable to indicate verbose output for debugging
         self.v = verbose
 
-        # Open the file and quit if the file does not exist
-        try:
-            self.fid = open(self.filename, 'rb')
-        except IOError as e:
-            print("I/O error({0}): {1}".format(e.errno, e.strerror))
-
-        # Store the original filename
-        self.dataOut['filename'] = self.filename
-
         self.parseHeader()
 
     def __del__(self):
@@ -128,7 +136,7 @@ class fileMRC:
         """
         if not self.fid.closed:
             if self.v:
-                print('Closing input file: {}'.format(self.filename))
+                print('Closing input file: {}'.format(str(self.file_path)))
             self.fid.close()
         return None
 
@@ -311,7 +319,7 @@ class fileMRC:
         # Add relevant information (metadata) to the output dictionary
         self.dataOut = {'pixelSize': self.voxelSize, 'voxelSize': self.voxelSize,
                         'cellAngles': self.cellAngles, 'axisOrientations': self.axisOrientations,
-                        'filename': self.filename}
+                        'filename': self.file_name}
         if self.extra[1] != 0:
             self.dataOut['FEIinfo'] = self.FEIinfo
 
@@ -439,15 +447,18 @@ def mrcReader(file_name, verbose=False):
     Example
     -------
         Simply read in all data from disk into memory. This assumes the dataset is 3 dimensional:
-
-            >>> from ncempy.io import mrc
-            >>> import matplotlib.pyplot as plt
-            >>> mrc1 = mrc.mrcReader('filename.mrc')
-            >>> plt.imshow(mrc1['data'][0, :, :]) #show the first image in the data set
+        >> from ncempy.io import mrc
+        >> import matplotlib.pyplot as plt
+        >> mrc1 = mrc.mrcReader('filename.mrc')
+        >> plt.imshow(mrc1['data'][0, :, :]) #show the first image in the data set
     """
+    if isinstance(file_name, str):
+        file_name = Path(file_name)
+
     with fileMRC(file_name, verbose) as f1:  # open the file and init the class
         im1 = f1.getDataset()  # read in the dataset
 
+    im1['filename'] = file_name.name
     im1['pixelUnit'] = 'A'
 
     return im1  # return the data and metadata as a dictionary
